AsyncState<T> class sealed

Implementers
Available extensions
Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asyncFailedOrNull() AsyncFailed<T>?

Available on AsyncState<T>, provided by the FPAsyncState extension

asyncLoadedOrNull() AsyncLoaded<T>?

Available on AsyncState<T>, provided by the FPAsyncState extension

asyncLoadingOrNull() AsyncLoading<T>?

Available on AsyncState<T>, provided by the FPAsyncState extension

match<R>({required R asyncLoading(AsyncLoading<T> data), required R asyncLoaded(AsyncLoaded<T> data), required R asyncFailed(AsyncFailed<T> data)}) → R

Available on AsyncState<T>, provided by the FPAsyncState extension

matchOrElse<R>({R asyncLoading(AsyncLoading<T> data)?, R asyncLoaded(AsyncLoaded<T> data)?, R asyncFailed(AsyncFailed<T> data)?, required R orElse(AsyncState data)}) → R

Available on AsyncState<T>, provided by the FPAsyncState extension

maybeMatch<R>({R asyncLoading(AsyncLoading<T> data)?, R asyncLoaded(AsyncLoaded<T> data)?, R asyncFailed(AsyncFailed<T> data)?}) → R?

Available on AsyncState<T>, provided by the FPAsyncState extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited